##############################################
#
# Effects of drought selection on 
# neighbor interactions between plants,
# separtely for mixture and monoculture
# Corresponds to the results in Supplementary 
# Fig. 4 and Supplementary Table 6
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)

dat = read.csv("neighbor_interaction_data.csv")
str(dat)
summary(dat$NInt)
dat0 = subset(dat, !is.na(NInt))
# summary statistics
with(dat0, tapply(NInt, 
                  list(comb, drought, time),
                  mean))
with(dat0, tapply(NInt, 
                  list(comb, time),
                  length))

#---------------------------------
#
# 1. Pre-drought
#
#---------------------------------
d1 = subset(dat0, time == "Pre-drought")

# test the effects of drought selection on 
# neighbor interaction intensity, separately
# for mixture and monoculture
d1mix = subset(d1, comb == "mix")
d1mono = subset(d1, comb == "mono")

lmm1 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                  sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d1mix)
lmm1 = update(lmm1)
test.asreml(lmm1)

lmm2 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                  sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d1mono)
lmm2 = update(lmm2)
test.asreml(lmm2)

#---------------------------------
#
#    2. During drought
#
#---------------------------------
d2 = subset(dat0, time == "Drought")
d2mix = subset(d2, comb == "mix")
d2mono = subset(d2, comb == "mono")

lmm1 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d2mix)
lmm1 = update(lmm1)
test.asreml(lmm1) 

lmm2 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                  sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d2mono)
test.asreml(lmm2)

#-----------------------------
#
#   3. Post-drought
#
#-----------------------------
d3 = subset(dat0, time == "Post-drought")
d3mix = subset(d3, comb == "mix")
d3mono = subset(d3, comb == "mono")

lmm1 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d3mix)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
test.asreml(lmm1) 

lmm2 = asreml.nvc(NInt ~
                    Block
                  + drought,
                  random =~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d3mono)
lmm2 = update(lmm2)
test.asreml(lmm2)
