##############################################
#
# Effects of drought selection on 
# productivity stability, separately for
# mixture and monoculture
# Corresponds to the results in Supplementary 
# Fig. 3 and Supplementary Table 4
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)
dat = read.csv("stability_data.csv")
str(dat)

# summary statistics
y = c(dat$log_resist, 
      dat$log_recov,
      dat$log_resil)
drought = rep(dat$drought, 3)
comb = rep(dat$comb, 3)
g = rep(letters[1:3], each=nrow(dat))
d = data.frame(g, drought, comb, y)
(mu = tapply(d$y, list(d$g,
                      d$drought,
                      d$comb),
            mean, na.rm=T))

#------------------------------------
#   1.  Resistance
#------------------------------------
d0 = subset(dat, !is.na(log_resist))
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)
table(d0$comb)

mixd0 = subset(d0, comb == "mix")
monod0 = subset(d0, comb == "mono")

lmm1 = asreml.nvc(log_resist ~
                Block
              + drought
              + log_biom1,
              random = ~sp_comp +
                sp_comp:drought,
              keep.order = T, 
              data = mixd0)
test.asreml(lmm1)

lmm2 = asreml.nvc(log_resist ~
                Block
              + drought
              + log_biom1,
              random = ~sp_comp +
                sp_comp:drought,
              keep.order = T, 
              data = monod0)
lmm2 = update(lmm2)
test.asreml(lmm2)

#-------------------------
#     2. Recovery
#-------------------------
d0 = subset(dat, !is.na(log_recov))
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)
table(d0$comb)

mixd0 = subset(d0, comb == "mix")
monod0 = subset(d0, comb == "mono")

lmm1 = asreml.nvc(log_recov ~
                Block
              + drought
              + log_biom1,
              random = ~sp_comp +
                sp_comp:drought,
              keep.order = T, 
              data = mixd0)
lmm1 = update(lmm1)
test.asreml(lmm1)

lmm2 = asreml.nvc(log_recov ~
                Block
              + drought
              + log_biom1,
              random=~sp_comp + 
                sp_comp:drought,
              keep.order = T, 
              data = monod0)
test.asreml(lmm2)

#-------------------------
#     3. Resilience
#-------------------------
d0 = subset(dat, !is.na(log_resil))
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)
table(d0$comb)

mixd0 = subset(d0, comb == "mix")
monod0 = subset(d0, comb == "mono")

lmm1 = asreml.nvc(log_resil ~
                Block
              + drought
              + log_biom1,
              random = ~sp_comp +
                sp_comp:drought,
              keep.order = T, 
              data = mixd0)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
test.asreml(lmm1)

lmm2 = asreml.nvc(log_resil ~
                Block
              + drought
              + log_biom1,
              random = ~sp_comp +
                sp_comp:drought,
              keep.order = T, 
              data = monod0)
test.asreml(lmm2)
