##############################################
#
# Effects of drought selection on 
# trait dissimilarity between interacting
# species in mixtures before the novel
# drought in the glasshouse
# Corresponds to the results in Supplementary
# Fig. 8 and Supplementary Table 10
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)
dat = read.csv("trait_distance_data.csv")
str(dat)

#--------------------------------------
# attention to this pot ("B1P674")
# raw LA value may be inputed with
# error, which leads to large LMA
# LA of Alo.pra is 5.905 for this pot,
# while the second minimum LA of the 
# same species in mixtures is about 17.5,
# the medium is about 44.7
# so we deleted this pot in the analyses
# associated with LA and LMA
#---------------------------------------

#---------------------------------
#
#         1. LMA
#
#---------------------------------
summary(dat$LMA)
dat0 = subset(dat, !is.na(LMA))
dat0 = subset(dat0, Pot != "B1P674")
nrow(dat0)
tapply(dat0$LMA, dat0$drought, mean)

m1 = asreml.nvc(LMA ~
                  Block
                + drought,
                random = ~
                  sp_comp
                + sp_comp:drought,
                keep.order = T, data = dat0)
test.asreml(m1)

#-------------------------
#
#     2.  LA
#
#-------------------------
summary(dat$LA)
dat0 = subset(dat, !is.na(LA))
dat0 = subset(dat0, Pot != "B1P674")
nrow(dat0)
tapply(dat0$LA, dat0$drought, mean)

m1 = asreml.nvc(LA ~
                  Block
                + drought,
                random = ~
                  sp_comp+
                  sp_comp:drought,
                keep.order = T, data = dat0)
m1 = update(m1)
test.asreml(m1)

# stratum variances and denDF are problematic
# in m1, so that we use aov instead, testing 
# the significance of drought selection using
# sp_comp:drought as error term

lm1 = aov(terms(LA ~
                  Block
                + sp_comp
                + drought
                + sp_comp:drought,
                keep.order = T), data = dat0)
summary(lm1)
aov.ftest(lm1, drought~sp_comp:drought,table=T)

#---------------------------------------------
#
# 3. Relative chlorophyll content (SPAD)
#
#---------------------------------------------
summary(dat$SPAD)
dat0 = subset(dat, !is.na(SPAD))
nrow(dat0)
tapply(dat0$SPAD, dat0$drought, mean)

m1 = asreml.nvc(SPAD ~
                  Block
                + drought,
                random = ~
                  sp_comp +
                  sp_comp:drought,
                keep.order = T, data = dat0)
m1 = update(m1)
m1 = update(m1)
test.asreml(m1)

#------------------------------
#
#  4. Multiple traits
#
#------------------------------
dat0 = subset(dat, !is.na(md))
nrow(dat0)
tapply(dat0$md, dat0$drought, mean)

m1 = asreml.nvc(md ~
                 Block
               + drought,
               random = ~
                 sp_comp +
                 sp_comp:drought,
               keep.order = T, 
               data = dat0)
test.asreml(m1)
